aboutsummaryrefslogtreecommitdiffstatshomepage
path: root/tbl_term.c
diff options
context:
space:
mode:
authorIngo Schwarze <schwarze@openbsd.org>2018-11-29 23:08:13 +0000
committerIngo Schwarze <schwarze@openbsd.org>2018-11-29 23:08:13 +0000
commita73ce50449b9ea611775c6c50b7fd42d08d80ae9 (patch)
treedd7755dbd4914a9d6c99b50f5ec83d3bd162e2c3 /tbl_term.c
parent1edc0ef397c19f417d5da6673ad13ff9347397f4 (diff)
downloadmandoc-a73ce50449b9ea611775c6c50b7fd42d08d80ae9.tar.gz
mandoc-a73ce50449b9ea611775c6c50b7fd42d08d80ae9.tar.zst
mandoc-a73ce50449b9ea611775c6c50b7fd42d08d80ae9.zip
Do not draw horizontal lines through vertical spans
which are requested in the data section rather than in the layout. Mini-feature found in misc/pfm(1).
Diffstat (limited to 'tbl_term.c')
-rw-r--r--tbl_term.c24
1 files changed, 19 insertions, 5 deletions
diff --git a/tbl_term.c b/tbl_term.c
index 9957ed8b..3bf48933 100644
--- a/tbl_term.c
+++ b/tbl_term.c
@@ -1,4 +1,4 @@
-/* $Id: tbl_term.c,v 1.64 2018/11/29 21:40:53 schwarze Exp $ */
+/* $Id: tbl_term.c,v 1.65 2018/11/29 23:08:13 schwarze Exp $ */
/*
* Copyright (c) 2009, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
* Copyright (c) 2011-2018 Ingo Schwarze <schwarze@openbsd.org>
@@ -579,8 +579,9 @@ static void
tbl_hrule(struct termp *tp, const struct tbl_span *spp,
const struct tbl_span *spn, int flags)
{
- const struct tbl_cell *cpp; /* Cell above this line. */
- const struct tbl_cell *cpn; /* Cell below this line. */
+ const struct tbl_cell *cpp; /* Layout cell above this line. */
+ const struct tbl_cell *cpn; /* Layout cell below this line. */
+ const struct tbl_dat *dpn; /* Data cell below this line. */
const struct roffcol *col; /* Contains width and spacing. */
int opts; /* For the table as a whole. */
int bw; /* Box line width. */
@@ -590,6 +591,13 @@ tbl_hrule(struct termp *tp, const struct tbl_span *spp,
cpp = spp == NULL ? NULL : spp->layout->first;
cpn = spn == NULL ? NULL : spn->layout->first;
+ dpn = NULL;
+ if (spn != NULL) {
+ if (spn->pos == TBL_SPAN_DATA)
+ dpn = spn->first;
+ else if (spn->next != NULL)
+ dpn = spn->next->first;
+ }
opts = spn == NULL ? spp->opts->opts : spn->opts->opts;
bw = opts & TBL_OPT_DBOX ? (tp->enc == TERMENC_UTF8 ? 2 : 1) :
opts & (TBL_OPT_BOX | TBL_OPT_ALLBOX) ? 1 : 0;
@@ -615,7 +623,9 @@ tbl_hrule(struct termp *tp, const struct tbl_span *spp,
/* Print the horizontal line inside this column. */
lw = cpp == NULL || cpn == NULL ||
- cpn->pos != TBL_CELL_DOWN ? hw : 0;
+ (cpn->pos != TBL_CELL_DOWN &&
+ (dpn == NULL || strcmp(dpn->string, "\\^") != 0))
+ ? hw : 0;
tbl_direct_border(tp, BHORIZ * lw,
col->width + col->spacing / 2);
@@ -641,6 +651,8 @@ tbl_hrule(struct termp *tp, const struct tbl_span *spp,
dw = 1;
}
cpn = cpn->next;
+ while (dpn != NULL && dpn->layout != cpn)
+ dpn = dpn->next;
}
if (cpp == NULL && cpn == NULL)
break;
@@ -655,7 +667,9 @@ tbl_hrule(struct termp *tp, const struct tbl_span *spp,
/* The horizontal line inside the next column. */
rw = cpp == NULL || cpn == NULL ||
- cpn->pos != TBL_CELL_DOWN ? hw : 0;
+ (cpn->pos != TBL_CELL_DOWN &&
+ (dpn == NULL || strcmp(dpn->string, "\\^") != 0))
+ ? hw : 0;
/* The line crossing at the end of this column. */